@@ -46,7 +46,7 @@ cb_about_click (GtkWidget *widget, gpointer user_data)
     GdkPixbuf *logo = NULL;
     gchar *logo_fn;
 
-    logo_fn = gnome_pixmap_file("gcharmap-logo.png");
+    logo_fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gcharmap-logo.png", TRUE, NULL);
     if (logo_fn != NULL)
     {
 	    logo = gdk_pixbuf_new_from_file(logo_fn, NULL /* error */);
@@ -78,9 +78,9 @@ void
 cb_charbtn_click (GtkButton *button, gpointer user_data)
 {
     GtkLabel *label = GTK_LABEL (GTK_BIN (button)->child);
-    gchar *text;
+    const gchar *text;
 
-    gtk_label_get (label, &text);
+    text = gtk_label_get_text (label);
 
     if (strcmp (text, _("del")) == 0) {
 	    if ( ! mainapp->insert_at_end) {
@@ -108,20 +108,26 @@ cb_charbtn_click (GtkButton *button, gpointer user_data)
 	    gint current_pos = gtk_editable_get_position(GTK_EDITABLE(mainapp->entry));
 	    gtk_editable_insert_text (GTK_EDITABLE (mainapp->entry), text,
 				      strlen (text), &current_pos);
+	    gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), current_pos + 1);
     } else {
-	    gtk_entry_append_text (GTK_ENTRY (mainapp->entry), text);
+           gint current_pos;
+           gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), -1);
+           current_pos = gtk_editable_get_position (GTK_EDITABLE (mainapp->entry));
+           gtk_editable_insert_text (GTK_EDITABLE (mainapp->entry), text, strlen(text), &current_pos);
+           gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), current_pos + 1);
     }
 }
 
 
-void
-cb_charbtn_enter (GtkButton *button, gpointer user_data)
+gboolean
+cb_charbtn_enter (GtkButton *button, GdkEventFocus *event, gpointer user_data)
 {
     GtkLabel *label = GTK_LABEL (GTK_BIN (button)->child);
-    gchar *text, *s;
+    gchar *s;
    int code;
+    const gchar *text;
 
-    gtk_label_get (label, &text);
+    text = gtk_label_get_text (label);
     if (strcmp (text, _("del")) == 0) {
 	    code = 127;
     } else {
@@ -134,16 +140,18 @@ cb_charbtn_enter (GtkButton *button, gpointer user_data)
     gtk_label_set_text (GTK_LABEL (mainapp->preview_label), text);
 #endif
     g_free (s);
+    return FALSE;
 }
 
 
-void
-cb_charbtn_leave (GtkButton *button, gpointer user_data)
+gboolean
+cb_charbtn_leave (GtkButton *button, GdkEventFocus *event, gpointer user_data)
 {
     gnome_appbar_pop (GNOME_APPBAR (GNOME_APP (mainapp->window)->statusbar));
 #if 0    
     gtk_label_set_text (GTK_LABEL (mainapp->preview_label), NULL);
 #endif
+    return FALSE;
 }
 
 
@@ -157,7 +165,16 @@ cb_clear_click (GtkWidget *widget, gpointer user_data)
 void
 cb_copy_click (GtkWidget *widget, gpointer user_data)
 {
-    cb_select_all_click (widget, user_data);
+    gint start, end;
+    gboolean selection_flag;
+
+    selection_flag = gtk_editable_get_selection_bounds (GTK_EDITABLE (mainapp->entry), &start, &end);
+
+    if(selection_flag)
+        gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), start, end);
+    else
+        cb_select_all_click (widget, user_data);
+
     gtk_editable_copy_clipboard (GTK_EDITABLE (mainapp->entry));
     gnome_app_flash (GNOME_APP (mainapp->window), _("Text copied to clipboard..."));
 }
@@ -166,10 +183,20 @@ cb_copy_click (GtkWidget *widget, gpointer user_data)
 void
 cb_cut_click (GtkWidget *widget, gpointer user_data)
 {
-    cb_select_all_click (widget, user_data);
+    gint start, end;
+    gboolean selection_flag;
+
+    selection_flag = gtk_editable_get_selection_bounds (GTK_EDITABLE (mainapp->entry), &start, &end);
+
+    if(selection_flag)
+        gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), start, end);
+    else
+        cb_select_all_click (widget, user_data);
+#if 0 /* Why the heck is this here? It makes cutting noticable slow */
     while (gtk_events_pending ()) gtk_main_iteration ();
     usleep (500000);
     while (gtk_events_pending ()) gtk_main_iteration ();
+#endif
     gtk_editable_cut_clipboard (GTK_EDITABLE (mainapp->entry));
     gnome_app_flash (GNOME_APP (mainapp->window), _("Text cut to clipboard..."));
 }
@@ -229,7 +256,7 @@ cb_paste_click (GtkWidget *widget, gpointer user_data)
 void
 cb_select_all_click (GtkWidget *widget, gpointer user_data)
 {
-    gtk_entry_select_region (GTK_ENTRY (mainapp->entry), 0, -1);
+    gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), 0, -1);
 }
 
 
