@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.20 2002/02/21 05:17:25 hadess Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.22 2002/03/21 03:33:47 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -47,6 +47,7 @@ static gchar *typeface_sel_names[NUM_TYPEFACES] = {
 #define NUM_TYPEFACE_ROWS 4
 #define NUM_TYPEFACE_COLS 2
 
+GtkWidget *db_label, *strat_label;
 static gint gdict_pref_dialog_signals[LAST_SIGNAL] = { 0 };
 extern GConfClient *client;
 
@@ -165,7 +166,7 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
 static void
 create_dialog (GDictPrefDialog *pref_dialog)
 {
-    GtkWidget *label, *alignment;
+    GtkWidget *server_label, *port_label, *alignment;
     GtkWidget *vbox, *table;
     GtkWidget *button;    
     gchar *port_str;
@@ -186,7 +187,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_set_col_spacings (pref_dialog->table, 6);
 
     pref_dialog->smart_lookup_btn = 
-        GTK_CHECK_BUTTON (gtk_check_button_new_with_label (_("Smart lookup")));
+        GTK_CHECK_BUTTON (gtk_check_button_new_with_mnemonic (_("Smart _lookup")));
     g_signal_connect (G_OBJECT (pref_dialog->smart_lookup_btn), "toggled",
     		      G_CALLBACK (smart_lookup_cb), pref_dialog);
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
@@ -197,20 +198,23 @@ create_dialog (GDictPrefDialog *pref_dialog)
                                GTK_WIDGET (pref_dialog->server_entry), 
                                1, 2, 0, 1);
     
-    label = gtk_label_new (_("Server:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 0, 1);
+    server_label = gtk_label_new (_("Server:"));
+    gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (server_label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, server_label, 0, 1, 0, 1);
     
     button = gtk_button_new_with_mnemonic (_("Set _Server"));
     gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (server_button_cb), pref_dialog);
 
-    label = gtk_label_new (_("Port:"));
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 1, 2);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    if( gail_loaded )
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Set the dictionary server"));
+
+    port_label = gtk_label_new (_("Port:"));
+    gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
+    gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (port_label), 1, 0.5);
 
     pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
     gtk_table_attach_defaults (pref_dialog->table, 
@@ -222,17 +226,32 @@ create_dialog (GDictPrefDialog *pref_dialog)
     g_signal_connect (G_OBJECT (button), "clicked",
     		      G_CALLBACK (port_button_cb), pref_dialog);
     
-    label = gtk_label_new (_("Database:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 3, 4);
+    if( gail_loaded )
+    {
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Set the port number"));
+        add_atk_namedesc(server_label, _("Server"), _("Server"));
+        add_atk_namedesc( GTK_WIDGET (pref_dialog->server_entry), _("Server Entry"), _("Enter the Server Name"));
+        add_atk_relation(server_label, GTK_WIDGET (pref_dialog->server_entry), ATK_RELATION_LABEL_FOR);
+        add_atk_relation( GTK_WIDGET (pref_dialog->server_entry), server_label, ATK_RELATION_LABELLED_BY);
+
+        add_atk_namedesc(port_label, _("Port"), _("Port"));
+        add_atk_namedesc( GTK_WIDGET(pref_dialog->port_entry), _("Port Entry"), _("Enter the Port Number"));
+        add_atk_relation(port_label, GTK_WIDGET(pref_dialog->port_entry), ATK_RELATION_LABEL_FOR);
+        add_atk_relation( GTK_WIDGET(pref_dialog->port_entry), port_label, ATK_RELATION_LABELLED_BY);
+
+    }
+
+    db_label = gtk_label_new_with_mnemonic (_("_Database:"));
+    gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (db_label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, db_label, 0, 1, 3, 4);
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
-    label = gtk_label_new (_("Default strategy:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 4, 5);
+    strat_label = gtk_label_new_with_mnemonic (_("D_efault strategy:"));
+    gtk_label_set_justify (GTK_LABEL (strat_label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (strat_label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, strat_label, 0, 1, 4, 5);
     pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
     
@@ -563,9 +582,31 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         
         if (command->cmd == C_SHOW_DB)
+        {
 	    pref_dialog->db_sel = option_menu;
+            gtk_label_set_mnemonic_widget (GTK_LABEL (db_label), GTK_WIDGET (pref_dialog->db_sel));
+
+            if ( gail_loaded)
+            {
+                add_atk_namedesc(db_label, _("Database"), _("Database Name"));
+                add_atk_relation(db_label, GTK_WIDGET (option_menu), ATK_RELATION_LABEL_FOR);
+                add_atk_relation( GTK_WIDGET (option_menu), db_label, ATK_RELATION_LABELLED_BY);
+
+            }
+        }
         else if (command->cmd == C_SHOW_STRAT)
+        {
 	    pref_dialog->strat_sel = option_menu;
+            gtk_label_set_mnemonic_widget (GTK_LABEL (strat_label), GTK_WIDGET (pref_dialog->strat_sel));
+
+            if ( gail_loaded )
+            {
+                add_atk_namedesc(strat_label, _("Default Strategy"), _("Default Strategy"));
+                add_atk_relation(strat_label, GTK_WIDGET (option_menu), ATK_RELATION_LABEL_FOR);
+                add_atk_relation( GTK_WIDGET (option_menu), strat_label, ATK_RELATION_LABELLED_BY);
+
+            }
+        }
     }
 }
 
@@ -586,49 +627,19 @@ server_button_cb (GtkButton *button, gpointer data)
     if ((server != NULL)
 		    && ((gdict_pref.server == NULL)
 			    || (strcmp (gdict_pref.server, server)))) {
-	gchar *old_server;
 	
-        old_server = gdict_pref.server;
+	if (gdict_pref.server)
+		g_free (gdict_pref.server);
         gdict_pref.server = g_strdup(server);
-
-        /* Try connecting. If we fail, restore the old config and abort */
-        if (gdict_init_context ()) {
-        	        GtkWidget *dialog;
-        	        
-        	        dialog = gtk_message_dialog_new (NULL,
-        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-        	                                         GTK_MESSAGE_ERROR,
-        	                                         GTK_BUTTONS_OK,
-        	                                         "%s",
-        	                                         _("The server you specified could not be found."));
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-			g_free (gdict_pref.server);
-			gdict_pref.server = old_server;
-			gdict_init_context ();
-			if (gdict_pref.server != NULL)
-				gtk_entry_set_text
-					(GTK_ENTRY (pref_dialog->server_entry),
-					            gdict_pref.server);
-			else
-				gtk_entry_set_text
-					(GTK_ENTRY (pref_dialog->server_entry),
-					            "");
-			return;
-		}
-	else {
-        
-            pref_dialog->context = context;
-        
-            g_free (old_server);
-            
-            pref_dialog_reset_db (pref_dialog);
-            pref_dialog_reset_strat (pref_dialog);
+        gdict_init_context ();
+        pref_dialog->context = context;
+        pref_dialog_reset_db (pref_dialog);
+        pref_dialog_reset_strat (pref_dialog);
            
-            gconf_client_set_string (client, "/apps/gdict/server", gdict_pref.server, NULL);
-        }
+        gconf_client_set_string (client, "/apps/gdict/server", gdict_pref.server, NULL);
+
     }
-    
+   
     if (server)
     	g_free (server);
 }
@@ -645,41 +656,20 @@ port_button_cb (GtkButton *button, gpointer data)
     
     if (gdict_pref.port != atoi (port)) {
     
-        old_port = gdict_pref.port;
         gdict_pref.port = atoi (port);
-        /* Try connecting. If we fail, restore the old config and abort */
-        if (gdict_init_context ()) {
-        	        GtkWidget *dialog;
-        	        gchar *port_str;
-        	        
-        	        dialog = gtk_message_dialog_new (NULL,
-        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-        	                                         GTK_MESSAGE_ERROR,
-        	                                         GTK_BUTTONS_OK,
-        	                                         "%s",
-        	                                         _("The server could not be found on that port."));
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-			g_free (gdict_pref.server);
-			gdict_pref.port = old_port;
-			gdict_init_context ();
-			port_str = g_strdup_printf("%d", (int) gdict_pref.port);
-    			gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
-    			g_free(port_str);
-			return;
-		}
-	else {
+        gdict_init_context ();
         
-            pref_dialog->context = context;
+        pref_dialog->context = context;
         
-            pref_dialog_reset_db (pref_dialog);
-            pref_dialog_reset_strat (pref_dialog);
+        pref_dialog_reset_db (pref_dialog);
+        pref_dialog_reset_strat (pref_dialog);
             
-            gconf_client_set_int (client, "/apps/gdict/port", gdict_pref.port, NULL);
-        }
+        gconf_client_set_int (client, "/apps/gdict/port", gdict_pref.port, NULL);
+       
     }
     
-    g_free (port);
+    if (port)
+    	g_free (port);
 }
 
 static void 
